import sys
import getopt
from qsqrcode.qrcode import Qrcode


def main():
    try:
        opts, args = getopt.getopt(sys.argv[1:], "hl:w:p:", ["level=", "word=", "path="])
    except getopt.GetoptError:
        print('qsqrcode.py -l <ecc_level> -w <word>')
        sys.exit(2)

    ecc_level = 'L'
    word = 'nothing input'
    save_path = 'default.png'
    for opt, arg in opts:
        if opt == '-h':
            print('qsqrcode.py -l <ecc_level> -w <word>')
            sys.exit()
        if opt in ('-w', '--word'):
            word = arg
        if opt in ('-l', '--level'):
            ecc_level = arg
        if opt in ('-p', '--path'):
            save_path = arg

    Qrcode(word, ecc_level).generate(save_path)



from setuptools import setup

setup(name='qs-qrcode',
      version='1.1',
      author='Q',
      author_email='tomhaoye@gmail.com',
      description='generate qrcode',
      long_description=open("README.rst", encoding='UTF-8').read(),
      url='http://github.com/tomhaoye/qrcode',
      license='MIT',
      packages=['qsqrcode'],
      install_requires=[
          'reedsolo',
          'Pillow'
      ],
      classifiers=[
          "Intended Audience :: Developers",
          "Operating System :: OS Independent",
          "License :: OSI Approved :: MIT License",
          "Topic :: Multimedia :: Graphics",
          "Topic :: Software Development :: Libraries :: Python Modules",
          "Programming Language :: Python",
          "Programming Language :: Python :: 3.5",
          "Programming Language :: Python :: 3.6"
      ],
      entry_points={
          "console_scripts": [
              "qsqrcode = qsqrcode.commandline:main"
          ]
      },
      zip_safe=False)
